
[![](https://codecov.io/gh/nickderobertis/py-app-conf/branch/master/graph/badge.svg)](https://codecov.io/gh/nickderobertis/py-app-conf)

#  py-app-conf

## Overview

Strongly typed and validated configuration supporting multiple file types, dynamic instantiation, and environment variables

## Getting Started

Install `py-app-conf`:

```
pip install py-app-conf
```

A simple example:

```python
import pyappconf

# Do something with pyappconf
```

## Links

See the
[documentation here.](
https://nickderobertis.github.io/py-app-conf/
)

## Author

Created by Nick DeRobertis. MIT License.